"""KMeans clustering example."""

import pandas as pd

from sportydatagen.cluster.kmeans import cluster_kmeans, encode_labels
from sportydatagen.plot.kmeans_scatter_plot import plot_kmeans_scatter

data = pd.read_csv(
    '../../datasets/all_tcx_extracted_interval_metrics.csv', sep=';',
)
data = data.drop(columns=['file_name', 'merged_from'])
data = encode_labels(df_data=data)

# Cluster data, return dataframe with cluster column and KMeans object
df_kmeans, kmeans, pca_data = cluster_kmeans(
    df_data=data,
    n_clusters=10,
    random_state=0,
    n_components=18,
    column_name='KMeans_cluster',
)

print(df_kmeans.head(11))

# Plot the clusters in 2D
plt = plot_kmeans_scatter(
    df_data=pca_data,
    kmeans=kmeans,
    dot_size_for_scatter=10,
    dot_size_centroid=50,
    abscise=5,
    ordinate=6,
)
plt.show()
