"""Examples for csv_utils.py."""
from sport_activities_features import GPXFile
from sport_activities_features.tcx_manipulation import TCXFile

from sportydatagen.csv_utils import (
    check_file_delete_csv_if_columns_are_nan,
    delete_empty_csv_files,
    delete_unmatching_sportfiles_and_csvs,
    remove_empty_activities,
)
from sportydatagen.filetype import Filetype

# Parameters to set
sportfile_directory = './tcx/'
csv_directory = './tcx_csv/'
filetype = Filetype.TCX

if filetype == Filetype.TCX:
    sport_file = TCXFile()
elif filetype == Filetype.GPX:
    sport_file = GPXFile()

# Run functions

# Delete basically empty tcx/gpx files from sport file directory
delete_empty_csv = True

# Check if columns contain not nan in dataframe
# If check_delete_files = true, delete the csv file
check_delete_files = True

# Remove tcx/gpx files that return empty activites
delete_empty_activities = True

# Delete tcx/gpx files that are not in csv and vice versa
delete_unmatching_sportfiles_and_csv = True

if delete_empty_activities:
    # Read all files in directory
    all_files = sport_file.read_directory(sportfile_directory)  # type list
    # Remove empty activities
    remove_empty_activities(all_files)

if delete_empty_csv:
    delete_empty_csv_files(csv_directory=csv_directory)

if check_delete_files:
    # Check if columns are nan in dataframe
    # and delete corresponding csv file
    # Can set custom columns to check
    check_file_delete_csv_if_columns_are_nan(
        csv_directory=csv_directory,
        columns_to_check=None,
    )

if delete_unmatching_sportfiles_and_csv:
    delete_unmatching_sportfiles_and_csvs(
        sportfile_directory=sportfile_directory,
        csv_directory=csv_directory,
        filetype=filetype,
    )
