"""TCX/GPX feature extraction example."""
import pandas as pd

from sportydatagen.feature_extraction_utils import (
    extract_features_csv_files_directory_to_csv,
    extract_single_sportfile_metrics_to_csv,
)
from sportydatagen.filetype import Filetype

# TCX Example
extract_features_csv_files_directory_to_csv(
    sportfile_directory='./tcx/',
    input_csv_directory='./tcx_csv/',
    filetype=Filetype.TCX,
    output_file='./extracted_metrics/tcx_extracted_interval_metrics.csv',
)

# GPX Example
extract_features_csv_files_directory_to_csv(
    sportfile_directory='./gpx/',  # Original files
    input_csv_directory='./gpx_csv/',  # Converted csv files
    filetype=Filetype.GPX,  # Filetype of original files
    output_file='./extracted_metrics/gpx_extracted_interval_metrics.csv',
    # Output filepath / filename
)

# Extract single TCX file to dict
read_df_csv = pd.read_csv('./tcx_csv/1.csv', sep=';')
df_row = extract_single_sportfile_metrics_to_csv(
    read_df_csv=read_df_csv,
    sportfile_directory='./tcx/',
    original_filename='1.tcx',  # Original file is required
    # to calculate calories
    index=1,
)

print(df_row)

# Extract single TCX file to dict without original file
read_df_no_original_file = pd.read_csv('./tcx_csv/1.csv', sep=';')
df_row_no_original_file = extract_single_sportfile_metrics_to_csv(
    read_df_csv=read_df_no_original_file,
)

print(df_row_no_original_file)

# TCX Example without original files
extract_features_csv_files_directory_to_csv(
    input_csv_directory='./tcx_csv/',
    output_file='./extracted_metrics/dir_tcx_extracted_interval_metrics.csv',
)
