"""Plot PCA Retention value."""

import pandas as pd
from sklearn import decomposition

from sportydatagen.cluster.kmeans import (
    encode_labels,
)
from sportydatagen.plot.retention_value import plot_retention_value

# Set the number of clusters
n_clusters = 10
# Set the number of components to keep in PCA
n_components = 18

# Read data
df_data = pd.read_csv(
    '../../datasets/all_tcx_extracted_interval_metrics.csv', sep=';',
)
# Drop the index, file_name and merged_from string columns
df_data = df_data.drop(['index', 'file_name', 'merged_from'], axis=1)
# Encode the activity_type string column
standarized_data = encode_labels(df_data=df_data)

# Create the PCA model
pca = decomposition.PCA(n_components=n_components)
# PCA data transformation
pca_data = pca.fit_transform(standarized_data)
# Plot PCA retention value
plot = plot_retention_value(pca=pca)
# Show plot
plot.show()
