"""Example of how to return a random sample of data."""
import pandas as pd

from sportydatagen.return_random_data import (
    filter_returned_columns,
    return_condition_random_data,
    return_number_random_data,
    return_percent_random_data,
)

# Read file with extracted features - metrics
filepath = '../datasets/all_tcx_extracted_interval_metrics.csv'

# Set pandas options
pd.set_option('display.max_columns', None)

df_random_by_number = return_number_random_data(
    filepath,
    random_size=24,
    random_state=42,
)

df_random_by_percent = return_percent_random_data(
    filepath,
    random_percent=0.23,
    random_state=42,
)

df_random_by_conditions = return_condition_random_data(
    filepath,
    random_size=10,
    min_hr_min=70,
    max_hr_min=79,
    min_hr_max=162,
    min_duration=4200,
    max_duration=5000,
    activity_type='Running',
    random_state=42,
)

# Write df to csv named 'df_random_by_conditions.csv'
df_random_by_conditions.to_csv(
    'df_random_by_conditions.csv', sep=';', index=True,
)

print(df_random_by_conditions.head(10))

filtered_df = filter_returned_columns(
    columns_to_return=[
        'calories',
        'total_distance',
        'duration',
        'activity_type',
    ],
    df_to_filter=df_random_by_conditions,
)

print(filtered_df.head(10))
