"""Test ascent and descent calculation."""

import unittest

import pandas as pd

from sportydatagen.feature_extraction_utils import calculate_ascent_descent


class TestCalculateAscentDescent(unittest.TestCase):

    """Test ascent and descent calculation."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.df = pd.DataFrame(
            {
                'altitudes': [0, 10, 20, 15, 25, 10, 5],
            },
        )
        self.zero_ascent = 0
        self.zero_descent = 0
        self.thirty_ascent = 30
        self.twentyfive_descent = 25

    def test_calculate_ascent_descent(self: 'unittest') -> None:
        """Test ascent and descent calculation."""
        ascent, descent = calculate_ascent_descent(self.df)
        assert ascent == self.thirty_ascent
        assert descent == self.twentyfive_descent

    def test_calculate_ascent_descent_with_empty_dataframe(
        self: 'unittest',
    ) -> None:
        """Test ascent and descent calculation with empty dataframe.

        Ascent and descent should be 0, since there is no data.
        Program should not crash.
        """
        empty_df = pd.DataFrame()
        ascent, descent = calculate_ascent_descent(empty_df)
        assert ascent == self.zero_ascent
        assert descent == self.zero_descent

    def test_calculate_ascent_descent_with_single_row_dataframe(
        self: 'unittest',
    ) -> None:
        """Test ascent and descent calculation with single line dataframe."""
        single_line_df = pd.DataFrame(
            {
                'altitudes': [0],
            },
        )
        ascent, descent = calculate_ascent_descent(single_line_df)
        assert ascent == self.zero_ascent
        assert descent == self.zero_descent
