"""Test calculate_duration function."""
import unittest

import pandas as pd

from sportydatagen.feature_extraction_utils import calculate_duration


class TestCalculateDuration(unittest.TestCase):

    """Test calculate_duration function."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.timestamps = [
            '2023-01-01 00:00:00',
            '2023-01-01 00:10:00',
            '2023-01-01 00:20:00',
            '2023-01-01 00:30:00',
        ]
        # Duration of 30 minutes in seconds
        self.test_duration = 1800
        # Create dataframe with no timestamps column
        self.distances = [1, 2, 3]

    def test_calculate_duration_with_valid_input(self: 'unittest') -> None:
        """Test calculate_duration function with valid input."""
        # Create dataframe with timestamps
        read_df_tcx_csv = pd.DataFrame({'timestamps': self.timestamps})
        # Calculate duration
        duration = calculate_duration(read_df_tcx_csv)

        # Assert duration is 1800 seconds (30 minutes)
        assert duration == self.test_duration

    def test_calculate_duration_with_missing_timestamps(
        self: 'unittest',
    ) -> None:
        """Test calculate_duration function with missing timestamps."""
        # Create dataframe with no timestamps column
        read_df_tcx_csv = pd.DataFrame({'distances': self.distances})

        # Expect KeyError
        with unittest.TestCase.assertRaises(self, KeyError):
            calculate_duration(read_df_tcx_csv)
