"""Test check_file_type function."""
import unittest

from sport_activities_features import GPXFile, TCXFile

from sportydatagen.convert_to_csv import check_file_type


class MyTestCase(unittest.TestCase):

    """Test check_file_type."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.tcx_file = './tcx/1.tcx'
        self.gpx_file = './gpx/f1.gpx'
        self.tcx_class = TCXFile()
        self.gpx_class = GPXFile()
        self.random_file = 'random_file.txt'

    def test_tcx(self: 'unittest') -> None:
        """Test check_file_type function with valid TCX input."""
        sport_file = check_file_type(self.tcx_file)

        assert isinstance(sport_file, type(self.tcx_class))
        assert not isinstance(sport_file, type(self.gpx_class))
        assert sport_file is not None

    def test_gpx(self: 'unittest') -> None:
        """Test check_file_type function with valid GPX input."""
        sport_file = check_file_type(self.gpx_file)

        assert isinstance(sport_file, type(self.gpx_class))
        assert not isinstance(sport_file, type(self.tcx_class))
        assert type(sport_file) is not None

    def test_none(self: 'unittest') -> None:
        """Test check_file_type function with invalid input."""
        sport_file = check_file_type(self.random_file)

        assert not isinstance(sport_file, type(self.gpx_class))
        assert not isinstance(sport_file, type(self.tcx_class))
        assert sport_file is None
