"""Tests for csv_utils.py."""
import unittest

from sportydatagen.csv_utils import (
    create_list_of_all_possible_files,
    missing_csv_files,
)


class TestCSVutils(unittest.TestCase):

    """Tests for csv_utils.py."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.two = 2
        self.thousand = 1000
        self.threeonetwo = 312
        self.list_of_all_files_1000 = create_list_of_all_possible_files(
            self.thousand,
        )
        self.first_file = '1.csv'
        self.middle_file = '501.csv'
        self.last_file = '1000.csv'
        self.list_of_all_files_312 = create_list_of_all_possible_files(
            self.threeonetwo,
        )
        self.middle_file_312 = '156.csv'
        self.last_file_312 = '312.csv'

        self.list_of_missing_files = missing_csv_files(
            directory_path='./tests/tcx_csv/', number_of_files=self.two,
        )

    def test_create_list_of_all_possible_files(self: 'unittest') -> None:
        """Tests creation of list of all possible files."""
        assert len(self.list_of_all_files_1000) == self.thousand
        assert self.list_of_all_files_1000[0] == self.first_file
        assert self.list_of_all_files_1000[500] == self.middle_file
        assert self.list_of_all_files_1000[999] == self.last_file

        assert len(self.list_of_all_files_312) == self.threeonetwo
        assert self.list_of_all_files_312[0] == self.first_file
        assert self.list_of_all_files_312[155] == self.middle_file_312
        assert self.list_of_all_files_312[311] == self.last_file_312

    def test_missing_csv_files(self: 'unittest') -> None:
        """Tests missing csv files."""
        assert len(self.list_of_missing_files) == self.two
