"""Test the Filetype enum."""

import unittest

from sportydatagen.filetype import Filetype


class TestFiletype(unittest.TestCase):

    """Test the Filetype enum."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.one = 1
        self.two = 2
        self.three = 3
        self.str_tcx = 'Filetype.TCX'
        self.str_gpx = 'Filetype.GPX'
        self.str_unknown = 'Filetype.UNKNOWN'

    def test_filetype_enum_values(self: 'unittest') -> None:
        """Test the values of the Filetype enum."""
        assert Filetype.TCX.value == self.one
        assert Filetype.GPX.value == self.two
        assert Filetype.UNKNOWN.value == self.three

    def test_filetype_enum_names(self: 'unittest') -> None:
        """Test the names of the Filetype enum."""
        assert Filetype.TCX.name == 'TCX'
        assert Filetype.GPX.name == 'GPX'
        assert Filetype.UNKNOWN.name == 'UNKNOWN'

    def test_filetype_enum_membership(self: 'unittest') -> None:
        """Test the membership of the Filetype enum."""
        assert Filetype.TCX in Filetype
        assert Filetype.GPX in Filetype
        assert Filetype.UNKNOWN in Filetype

    def test_filetype_enum_comparison(self: 'unittest') -> None:
        """Test the comparison of the Filetype enum."""
        assert Filetype.TCX != Filetype.GPX
        assert Filetype.TCX != Filetype.UNKNOWN
        assert Filetype.GPX != Filetype.UNKNOWN

    def test_filetype_enum_str(self: 'unittest') -> None:
        """Test the str of the Filetype enum."""
        assert str(Filetype.TCX) == self.str_tcx
        assert str(Filetype.GPX) == self.str_gpx
        assert str(Filetype.UNKNOWN) == self.str_unknown
