"""Test saf extract metrics."""

import unittest
from pathlib import Path

import pandas as pd

from sportydatagen.saf_extract_features_to_csv import (
    saf_extract_metrics_convert_to_csv,
)


class TestSafExtractMetrics(unittest.TestCase):

    """Test saf extract metrics."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.sportfile_directory = './tests/tcx/'
        self.output_file = './saf_extracted_interval_metrics.csv'
        self.output_file_no_null = (
            './saf_extracted_interval_metrics_no_null.csv'
        )
        self.df_shape = (2, 15)
        self.activity_type = 'Biking'

        self.first_file_distance = 8869.41
        self.first_file_calories = 374
        self.first_file_hr_max = 173
        self.first_file_altitude_avg = 418.31
        self.first_file_altitude_min = 357.0
        self.first_file_descent = 208.2

        self.second_file_duration = 3876.0
        self.second_file_hr_avg = 167.48
        self.second_file_hr_min = 102
        self.second_file_altitude_max = 78.6
        self.second_file_ascent = 452.6
        self.second_file_filename = '2.tcx'

    def test_saf_extract_metrics_convert_to_csv(self: 'unittest') -> None:
        """Test saf extract metrics convert to csv function.

        Test sports activities features integral metrics extraction
         and conversion to .csv file. Test if the output file exists,
         has the correct shape and contains the correct values.
        In the end, delete the file and assert it is deleted
        """
        saf_extract_metrics_convert_to_csv(
            sportfile_directory=self.sportfile_directory,
            output_file=self.output_file,
        )

        assert Path.exists(Path(self.sportfile_directory))
        assert Path.exists(Path(self.output_file_no_null))

        test_df = pd.read_csv(self.output_file, sep=';')

        assert test_df.shape == self.df_shape
        assert test_df['activity_type'].iloc[0] == self.activity_type
        assert test_df['activity_type'].iloc[1] == self.activity_type
        assert test_df['distance'].iloc[0] == self.first_file_distance
        assert test_df['duration'].iloc[1] == self.second_file_duration
        assert test_df['calories'].iloc[0] == self.first_file_calories
        assert test_df['hr_avg'].iloc[1] == self.second_file_hr_avg
        assert test_df['hr_max'].iloc[0] == self.first_file_hr_max
        assert test_df['hr_min'].iloc[1] == self.second_file_hr_min
        assert test_df['altitude_avg'].iloc[0] == self.first_file_altitude_avg
        assert test_df['altitude_max'].iloc[1] == self.second_file_altitude_max
        assert test_df['altitude_min'].iloc[0] == self.first_file_altitude_min
        assert test_df['ascent'].iloc[1] == self.second_file_ascent
        assert test_df['descent'].iloc[0] == self.first_file_descent
        assert test_df['filename'].iloc[1] == self.second_file_filename

        Path.unlink(Path(self.output_file))
        Path.unlink(Path(self.output_file_no_null))

        assert not Path.exists(Path(self.output_file))
        assert not Path.exists(Path(self.output_file_no_null))
