"""Test sportydatagen."""

import unittest
from pathlib import Path

from sportydatagen.convert_to_csv import (
    convert_directory_of_files_to_csv,
    convert_single_file,
)


def convert_directory_sport_files(
    input_sportfile_directory: str,
    output_csv_dir: str,
    file1: str,
    file2: str,
) -> None:
    """Convert directory of sport files to CSV files."""
    convert_directory_of_files_to_csv(
        input_sportfile_directory=input_sportfile_directory,
        output_csv_dir=output_csv_dir,
    )
    assert Path.exists(Path(file1))
    assert Path.exists(Path(file2))
    Path.unlink(Path(file1))
    Path.unlink(Path(file2))
    assert not Path.exists(Path(file1))
    assert not Path.exists(Path(file2))


class TestConversionToCSV(unittest.TestCase):

    """Test file conversion to csv."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.gpx_file_1 = './tests/gpx/f2.gpx'
        self.gpx_csv_file_1 = './tests/gpx_csv/f2.csv'
        self.gpx_file_2 = './tests/gpx/f3.gpx'
        self.gpx_csv_file_2 = './tests/gpx_csv/f3.csv'
        self.gpx_directory = './tests/gpx/'
        self.gpx_csv_directory = './tests/gpx_csv/'

        self.tcx_file_1 = './tests/tcx/1.tcx'
        self.tcx_csv_file_1 = './tests/tcx_csv/1.csv'
        self.tcx_file_2 = './tests/tcx/2.tcx'
        self.tcx_csv_file_2 = './tests/tcx_csv/2.csv'
        self.tcx_directory = './tests/tcx/'
        self.tcx_csv_directory = './tests/tcx_csv/'

    def test_convert_single_tcx_file(self: 'unittest') -> None:
        """Convert TCX file to CSV file."""
        convert_single_file(
            input_file=self.tcx_file_1,
            output_dir=self.tcx_csv_directory,
        )
        assert Path.exists(Path(self.tcx_csv_file_1))
        Path.unlink(Path(self.tcx_csv_file_1))
        assert not Path.exists(Path(self.tcx_csv_file_1))

    def test_convert_single_gpx_file(self: 'unittest') -> None:
        """Convert single GPX file to CSV file."""
        convert_single_file(
            input_file=self.gpx_file_1,
            output_dir=self.gpx_csv_directory,
        )
        assert Path.exists(Path(self.gpx_csv_file_1))
        Path.unlink(Path(self.gpx_csv_file_1))
        assert not Path.exists(Path(self.gpx_csv_file_1))

    def test_convert_directory_tcx_file(self: 'unittest') -> None:
        """Convert directory of TCX files to CSV files."""
        convert_directory_sport_files(
            input_sportfile_directory=self.tcx_directory,
            output_csv_dir=self.tcx_csv_directory,
            file1=self.tcx_csv_file_1,
            file2=self.tcx_csv_file_2,
        )

    def test_convert_directory_gpx_files(self: 'unittest') -> None:
        """Convert directory of GPX files to CSV files."""
        convert_directory_sport_files(
            input_sportfile_directory=self.gpx_directory,
            output_csv_dir=self.gpx_csv_directory,
            file1=self.gpx_csv_file_1,
            file2=self.gpx_csv_file_2,
        )
