"""Test sportydatagen utils.py."""

import unittest

from sportydatagen.utils import read_basic_dataset, read_dataset


class TestUtils(unittest.TestCase):

    """Test utils.py."""

    def setUp(self: 'unittest') -> None:
        """Set up test data."""
        self.basic_dataset = './datasets/dataset1.csv'
        self.basic_dataset_length = 306
        self.basic_dataset_activity_type = 'Biking'
        self.basic_dataset_total_duration = 8424.0
        self.basic_dataset_total_distance = 65452.07
        self.basic_dataset_calories = 1099.0
        self.full_dataset = (
            './datasets/tcx_sport5_2555_extracted_interval_metrics.csv'
        )
        self.full_dataset_activity_type = 'Biking'
        self.full_dataset_total_duration = 3240.0
        self.full_dataset_total_distance = 8869.41
        self.full_dataset_calories = 374.0
        self.full_dataset_avg_hr = 118.0
        self.full_dataset_min_hr = 77.0
        self.full_dataset_max_hr = 173.0
        self.full_dataset_avg_altitude = 418.31
        self.full_dataset_min_altitude = 357.0
        self.full_dataset_max_altitude = 483.2
        self.full_dataset_ascent = 245.8
        self.full_dataset_descent = 208.2
        self.full_dataset_max_speed = 70.67
        self.full_dataset_avg_speed = 11.0
        self.full_dataset_filename = '1.csv'

    def test_read_basic_dataset(self: 'unittest') -> None:
        """Test read_basic_dataset."""
        dataset = read_basic_dataset(self.basic_dataset)
        assert len(dataset) == self.basic_dataset_length
        activity = dataset[0]
        assert activity.get_activity_type() == self.basic_dataset_activity_type
        assert (
            activity.get_total_duration() == self.basic_dataset_total_duration
        )
        assert (
            activity.get_total_distance() == self.basic_dataset_total_distance
        )
        assert activity.get_calories() == self.basic_dataset_calories

    def test_read_tcx_dataset(self: 'unittest') -> None:
        """Test read_tcx_dataset."""
        tcx_dataset = read_dataset(self.full_dataset)
        activity = tcx_dataset[0]
        assert activity.get_activity_type() == self.full_dataset_activity_type
        assert (
            activity.get_total_duration() == self.full_dataset_total_duration
        )
        assert (
            activity.get_total_distance() == self.full_dataset_total_distance
        )
        assert activity.get_calories() == self.full_dataset_calories
        assert activity.get_avg_hr() == self.full_dataset_avg_hr
        assert activity.get_min_hr() == self.full_dataset_min_hr
        assert activity.get_max_hr() == self.full_dataset_max_hr
        assert activity.get_avg_altitude() == self.full_dataset_avg_altitude
        assert activity.get_min_altitude() == self.full_dataset_min_altitude
        assert activity.get_max_altitude() == self.full_dataset_max_altitude
        assert activity.get_ascent() == self.full_dataset_ascent
        assert activity.get_descent() == self.full_dataset_descent
        assert activity.get_max_speed() == self.full_dataset_max_speed
        assert activity.get_avg_speed() == self.full_dataset_avg_speed
        assert activity.get_file_name() == self.full_dataset_filename
